@@ -7,6 +7,7 @@
 #include "dolphinitemlistview.h"
 
 #include "dolphin_compactmodesettings.h"
+#include "dolphin_contentdisplaysettings.h"
 #include "dolphin_detailsmodesettings.h"
 #include "dolphin_generalsettings.h"
 #include "dolphin_iconsmodesettings.h"
@@ -81,6 +82,8 @@ void DolphinItemListView::readSettings()
     CompactModeSettings::self()->load();
     DetailsModeSettings::self()->load();
 
+    ContentDisplaySettings::self()->load();
+
     beginTransaction();
 
     setEnabledSelectionToggles(m_selectionTogglesEnabled);
@@ -234,3 +237,5 @@ void DolphinItemListView::updateGridSize()
     setItemSize(QSizeF(itemWidth, itemHeight));
     endTransaction();
 }
+
+#include "moc_dolphinitemlistview.cpp"
